Crate mkt_types

Crate mkt_types 

Stable business data types shared by mkt clients and strategy code.

Structs

Balance
ClientOrderId
Decimal
Decimal represents a 128 bit representation of a fixed-precision decimal number. The finite set of values of type Decimal are of the form m / 10e, where m is an integer such that -296 < m < 296, and e is an integer between 0 and 28 inclusive.
DerivativeKind
ExtensionExchangeId
Extensions
Fill
FuturesCancelOrderRequest
FuturesOrderQuery
FuturesOrderRequest
Kline
KlineRequest
LastPrice
LotSizeFilter
MarketInfo
NamespaceKey
NotionalConstraints
Order
OrderBook
OrderBookLevel
OrderId
Position
PriceFilter
SetLeverageRequest
SpotCancelOrderRequest
SpotOrderQuery
SpotOrderRequest
Symbol
Trade
TradingConstraints

Enums

ContractMaturity
ExchangeId
ExchangeIdParseError
ExtensionValueError
KlineInterval
Kline (candlestick) interval expressed as a unit plus count.
KnownExchange
MarginMode
MarketFamily
MarketKind
MarketKindParseError
MarketStatus
NamespaceKeyError
OrderKey
OrderSide
OrderStatus
OrderType
PositionSide
SettlementMode
TimeInForce
TradeSide